@@ -2,20 +2,18 @@
 #'
 #' @description
 #' Implementation of the OVCCoordenadas service
-#' [Consulta RCCOOR
-#' Distancia](https://ovc.catastro.meh.es/ovcservweb/ovcswlocalizacionrc/ovccoordenadas.asmx?op=Consulta_RCCOOR_Distancia).
+#' [Consulta RCCOOR Distancia](`r ovcurl("RCCOORD")`).
+#'
 #' Return the cadastral reference found on a set of coordinates. If no cadastral
-#' references are found, the API returns a list of
-#' the cadastral references found on an area of 50 square meters around the
-#' requested coordinates.
+#' references are found, the API returns a list of the cadastral references
+#' found on an area of 50 square meters around the requested coordinates.
 #'
 #' @references
-#' [Consulta RCCOOR
-#' Distancia](https://ovc.catastro.meh.es/ovcservweb/ovcswlocalizacionrc/ovccoordenadas.asmx?op=Consulta_RCCOOR_Distancia)
+#' [Consulta RCCOOR Distancia](`r ovcurl("RCCOORD")`).
 #'
 #' @family OVCCoordenadas
 #' @family cadastral references
-#' @seealso [catr_srs_values], `vignette("ovcservice")`
+#' @seealso [catr_srs_values], `vignette("ovcservice", package = "CatastRo")`
 #' @inheritParams catr_atom_get_address
 #'
 #' @param lat Latitude to use on the query. It should be specified in the same
@@ -25,24 +23,23 @@
 #' @param srs SRS/CRS to use on the query. To check the admitted values check
 #'   [catr_srs_values], specifically the `ovc_service` column.
 #'
-#' @return A \CRANpkg{tibble}. See **Details**
+#' @return A [`tibble`][tibble::tibble]. See **Details**
 #'
 #' @export
 #'
 #' @details
 #'
 #' When the API does not provide any result, the function returns a
-#' \CRANpkg{tibble} with the input parameters only.
+#' [`tibble`][tibble::tibble] with the input parameters only.
 #'
-#' On a successful query, the function returns a \CRANpkg{tibble} with one row
-#' by cadastral reference, including the following columns:
+#' On a successful query, the function returns a [`tibble`][tibble::tibble] with
+#' one row by cadastral reference, including the following columns:
 #' * `geo.xcen`, `geo.ycen`, `geo.srs`: Input parameters of the query.
-#' * `refcat`: Cadastral Reference.
+#' * `refcat`: Cadastral reference.
 #' * `address`: Address as it is recorded on the Cadastre.
-#' * `cmun_ine`: Municipality Code as registered on the INE (National
+#' * `cmun_ine`: Municipality code as registered on the INE (National
 #'    Statistics Institute).
-#' * Rest of fields: Check the API Docs on [Consulta RCCOOR
-#' Distancia](https://ovc.catastro.meh.es/ovcservweb/ovcswlocalizacionrc/ovccoordenadas.asmx?op=Consulta_RCCOOR_Distancia)
+#' * Rest of fields: Check the API Docs.
 #'
 #' @examplesIf tolower(Sys.info()[["sysname"]]) != "linux"
 #' \donttest{
@@ -78,37 +75,33 @@ catr_ovc_get_rccoor_distancia <- function(lat, lon, srs = 4326,
     "OVCSWLocalizacionRC/OVCCoordenadas.asmx/Consulta_RCCOOR_Distancia"
   )
 
-
-  ## GET
-
-  if (verbose) {
-    url <- httr::parse_url(api_entry)
-    url <- httr::modify_url(url, query = list(
-      SRS = srs,
-      Coordenada_X = lon,
-      Coordenada_Y = lat
-    ))
-
-    message("Querying url:\n\t", url)
-  }
-
-
-
-  api_res <- httr::GET(api_entry, query = list(
+  query <- list(
     SRS = srs,
     Coordenada_X = lon,
     Coordenada_Y = lat
-  ))
+  )
 
+  ## GET
+  url <- httr2::url_parse(api_entry)
+  url$query <- query
+  url <- httr2::url_build(url)
+
+  if (verbose) {
+    message("Querying url:\n\t", url)
+  }
+
+  api_res <- httr2::request(url)
+  api_res <- httr2::req_perform(api_res)
 
   # Check error on status
-  httr::stop_for_status(api_res)
-
+  httr2::resp_check_status(api_res)
 
   # Extract results
-  content <- httr::content(api_res)
+  content <- httr2::resp_body_xml(api_res)
   content_list <- xml2::as_list(content)
+  # nolint start
   res <- content_list[["consulta_coordenadas_distancias"]][["coordenadas_distancias"]][["coordd"]]
+  # nolint end
 
   # Get overall info of the query
   overall <- unlist(res["geo"])
